Module point

Module point 

Structs

Point
Struct defining a point on the surface of a model grid (e.g. of a star or disc etc.) A Point has a position, a direction which is the surface normal, an area, a relative gravity, a vector of phase pairs defining when the point is eclipsed by another model component, and a flux.