rpot_grad computes the gradient in phi, lambda space of the Roche potential.
phi refers to the orbital phase, lambda to a multiplier that specified the position
of a point from an origin plus the multiplier time lambda.
rpot_val computes the value of the Roche potential for a specific value of phi & lambda.
phi refers to the orbital phase, lambda to a multiplier that specified the position
of a point from an origin plus the multiplier time lambda.
rpot_val_grad computes the value & gradient in phi, lambda space of the Roche potential.
phi orbital phase, lambda a multiplier that specified the position
of a point from an origin plus the multiplier times lambda.