sphere_eclipse tells you whether or not a given sphere will eclipse a
given point or not. If the answer is yes, it will also return with four
parameters to define the phase range and the multiplier range delimiting the
region within which the spheres surface is crossed.
These can then be used as the starting point for later computation.
(The line of sight is described as the point in question plus a scalar multiplier
times a unit vector pointing towards Earth – this is the “multiplier” referred to above
and below). The multiplier must be positive: in other words the routine does not
project backwards. If the point in inside the sphere, phi1 will be set = 0, phi2 = 1,
lam1 = 0, and lam2 = the largest value of the multiplier lambda
This version of sphere_eclipse tells you whether or not a given sphere will eclipse
a given point at a particular phase or not. If the answer is yes,
it will also return with the multiplier values giving the cut points. These can then
be used as starting points for Roche lobe computations. These can then be used as the
starting point for later computation. Points inside the sphere are regarded as being
eclipsed with the lower mulitplier set = 0
This version of sphere_eclipse tells you whether or not a given sphere will eclipse
a given point at a particular phase or not. If the answer is yes,
it will also return with the multiplier values giving the cut points. These can then
be used as starting points for Roche lobe computations. These can then be used as the
starting point for later computation. Points inside the sphere are regarded as being
eclipsed with the lower multiplier set = 0.
The multiplier along the line of sight is lambda, with the smallest and largest values
returned as lam1 and lam2, respectively.
sphere_eclipse tells you whether or not a given sphere will eclipse a
given point or not. If the answer is yes, it will also return with four
parameters to define the phase range and the multiplier range delimiting the
region within which the spheres surface is crossed.
These can then be used as the starting point for later computation.
(The line of sight is described as the point in question plus a scalar multiplier
times a unit vector pointing towards Earth – this is the “multiplier” referred to above
and below). The multiplier must be positive: in other words the routine does not
project backwards. If the point in inside the sphere, phi1 will be set = 0, phi2 = 1,
lam1 = 0, and lam2 = the largest value of the multiplier lambda