Module stream_physics

Module stream_physics 

Structs

OrbitalSystem

Functions

brightspot_position
brightspot_position runs strinit then stradv to get the coordinates of of the gas stream when it reaches a given radius from the primary star.
rocacc
rocacc calculates and returns the acceleration (in the rotating frame) in a Roche potential of a particle of given position and velocity.
stradv
stradv advances a particle of given position and velocity until it reaches a specified radius. It then returns with updated position and velocity. It is up to the user not to request a value that cannot be reached.
stradv_wrapper
stradv advances a particle of given position and velocity until it reaches a specified radius. It then returns with updated position and velocity. It is up to the user not to request a value that cannot be reached.
stream
stream works by integrating the equations of motion for the Roche potential using Burlisch-Stoer integration. Every time the distance from the last point exceeds step, it interpolates and stores a new point. This allows one not to spend loads of points on regions where nothing is happening.
streamr
streamr works by integrating the equations of motion for the Roche potential using Burlisch-Stoer integration. It stops when the stream reaches a target radius or a minimum radius, whichever is the larger.
strinit
strinit sets a particle just inside the L1 point with the correct velocity as given in Lubow and Shu.
strmnx
strmnx finds the next point at which stream is closest or furthest from primary.
strmnx_wrapper
Calculates position & velocity of n-th turning point of stream. x,y,vx1,vy1,vx2,vy2 = strmnx(q, n=1, acc=1.e-7), q = M2/M1. Two sets of velocities are reported, the first for the pure stream, the second for the disk at that point.