pub fn stradv_wrapper(
q: f64,
r: &Vec3,
v: &Vec3,
rad: f64,
acc: f64,
smax: f64,
) -> (f64, Vec3, Vec3)Expand description
stradv advances a particle of given position and velocity until it reaches a specified radius. It then returns with updated position and velocity. It is up to the user not to request a value that cannot be reached.
\param q mass ratio = M2/M1 \param r Initial position \param v Initial velocity \param rad Radius to aim for \param acc Accuracy with which to place output point at rad. \param smax Largest time step allowed. It is possible that the routine could take such a large step that it misses the point when the stream is inside the requested radius. This allows one to control this. Typical value = 1.e-3. \returns (timestep, new position, new velocity)