stream_py

Function stream_py 

pub fn stream_py(
    py: Python<'_>,
    q: f64,
    step: f64,
    n_points: usize,
) -> PyResult<(Py<PyArray1<f64>>, Py<PyArray1<f64>>)>
stream works by integrating the equations of motion for the Roche potential using Burlisch-Stoer integration. Every time the distance from the last point exceeds step, it interpolates and stores a new point. This allows one not to spend loads of points on regions where nothing is happening.

Arguments:

  • q: mass ratio = M2/M1. Stream flows from star 2 to 1.
  • step: step between points (units of separation).
  • n_points: number of points to compute.

Returns:

  • x: array of x values returned.
  • y: array of y values returned.