Module vstream_physics

Module vstream_physics 

Functions

vstream
vstream computes the path of the gas stream in a binary in velocity space. There are a few different options for the type of stream velocities produced. vstream works by integrating the equations of motion for the Roche potential using Burlisch-Stoer integration. Every time the speed changes by step, it interpolates and stores a new point.
vstream_reg
vstream_reg_py