pub struct Point {
pub position: Vec3,
pub direction: Vec3,
pub area: f32,
pub gravity: f32,
pub eclipse: Etype,
pub flux: f32,
}Expand description
Struct defining a point on the surface of a model grid (e.g. of a star or disc etc.)
A Point has a position, a direction which is the surface normal, an area,
a relative gravity, a vector of phase pairs defining when the point is eclipsed by
another model component, and a flux.
Fields
position: Vec3direction: Vec3area: f32gravity: f32eclipse: Etypeflux: f32Implementations
Sourceimpl Point
impl Point
Sourcepub fn new(
position: Vec3,
direction: Vec3,
area: f64,
gravity: f64,
eclipse: Etype,
) -> Self
pub fn new( position: Vec3, direction: Vec3, area: f64, gravity: f64, eclipse: Etype, ) -> Self
Creates a new Point.
Sourcepub fn is_visible(&self, phase: f64) -> bool
pub fn is_visible(&self, phase: f64) -> bool
checks that the given phase is not during one of the phase ranges when the point is eclipsed.
Sourcepub fn is_visible_phase_normed(&self, phase: f64) -> bool
pub fn is_visible_phase_normed(&self, phase: f64) -> bool
This version of is_visible will not correct for phases outside of expected range to speed up large loops. run phase = phase - phase.floor(); outside of loop beforehand