pub fn sphere_eclipse_vector_wrapper(
earth: &Vec3,
r: &Vec3,
c: &Vec3,
rsphere: f64,
) -> (bool, f64, f64)Expand description
This version of sphere_eclipse tells you whether or not a given sphere will eclipse a given point at a particular phase or not. If the answer is yes, it will also return with the multiplier values giving the cut points. These can then be used as starting points for Roche lobe computations. These can then be used as the starting point for later computation. Points inside the sphere are regarded as being eclipsed with the lower multiplier set = 0. The multiplier along the line of sight is lambda, with the smallest and largest values returned as lam1 and lam2, respectively.
Arguments:
earth: vector towards Earthr: the position vector of the point in question (units of binary separation)c: the centre of the sphere (units of binary separation)rsphere: the radius defining the sphere enclosing the star (units of binary separation)
Returns:
- (eclipsed, lam1, lam2)