stradv advances a particle of given position and velocity until
it reaches a specified radius. It then returns with updated position and
velocity. It is up to the user not to request a value that cannot be reached.
stradv advances a particle of given position and velocity until
it reaches a specified radius. It then returns with updated position and
velocity. It is up to the user not to request a value that cannot be reached.
stream works by integrating the equations of motion for the Roche
potential using Burlisch-Stoer integration. Every time the distance
from the last point exceeds step, it interpolates and stores a new
point. This allows one not to spend loads of points on regions where
nothing is happening.
streamr works by integrating the equations of motion for the Roche
potential using Burlisch-Stoer integration. It stops when the stream
reaches a target radius or a minimum radius, whichever is the larger.
Calculates position & velocity of n-th turning point of stream.
x,y,vx1,vy1,vx2,vy2 = strmnx(q, n=1, acc=1.e-7), q = M2/M1.
Two sets of velocities are reported, the first for the pure stream,
the second for the disk at that point.