stradv advances a particle of given position and velocity until
it reaches a specified radius. It then returns with updated position and
velocity. It is up to the user not to request a value that cannot be reached.
stradv advances a particle of given position and velocity until
it reaches a specified radius. It then returns with updated position and
velocity. It is up to the user not to request a value that cannot be reached.