pub fn strmnx_wrapper(
q: f64,
n: usize,
acc: f64,
) -> Result<(f64, f64, f64, f64, f64, f64), RocheError>Expand description
Calculates position & velocity of n-th turning point of stream. x,y,vx1,vy1,vx2,vy2 = strmnx(q, n=1, acc=1.e-7), q = M2/M1. Two sets of velocities are reported, the first for the pure stream, the second for the disk at that point.
Arguments:
q: mass ratio = M2/M1n: turning point numberacc: accuracy in time to locate minimum/maximum.
Returns: (x, y, vx1, vy1, vx2, vy2)